@@ -9,12 +9,12 @@ import (
 	"errors"
 	"fmt"
 	"io"
-	"io/ioutil"
 	"log"
 	"os"
 	"os/user"
 	"path/filepath"
 	"regexp"
+	"strconv"
 	"strings"
 
 	"github.com/klauspost/compress/zstd"
@@ -39,6 +39,8 @@ var (
 	ErrNonDefinition = errors.New("no definition")
 )
 
+var importCount int
+
 // Importer is the interface import data into the database.
 // Importer parses sql query to decide which file to Import.
 // Therefore, the reader does not receive it directly.
@@ -128,7 +130,7 @@ func TableNames(parsedQuery []string) (map[string]string, []int) {
 	debug.Printf("[%s]", strings.Join(parsedQuery, "]["))
 	for i, w := range parsedQuery {
 		switch {
-		case strings.Contains(" \t\r\n;=", w):
+		case strings.Contains(" \t\r\n;=", w): // nolint // Because each character is parsed by SQLFields.
 			continue
 		case strings.EqualFold(w, "FROM"),
 			strings.EqualFold(w, "JOIN"),
@@ -218,6 +220,7 @@ func ImportFile(db *DB, fileName string, readOpts *ReadOpts) (string, error) {
 // Wildcards can be passed as fileName.
 func ImportFileContext(ctx context.Context, db *DB, fileName string, readOpts *ReadOpts) (string, error) {
 	opts, fileName := guessOpts(*readOpts, fileName)
+	importCount++
 	file, err := importFileOpen(fileName)
 	if err != nil {
 		debug.Printf("%s\n", err)
@@ -237,7 +240,7 @@ func ImportFileContext(ctx context.Context, db *DB, fileName string, readOpts *R
 
 	tableName := db.QuotedName(fileName)
 	if opts.InJQuery != "" {
-		tableName = db.QuotedName(fileName + "::" + opts.InJQuery)
+		tableName = db.QuotedName(fileName + "::" + "jq" + strconv.Itoa(importCount))
 	}
 
 	columnNames, err := reader.Names()
@@ -327,9 +330,9 @@ func uncompressedReader(reader io.Reader) io.ReadCloser {
 	n, err := io.ReadAtLeast(reader, buf[:], len(buf))
 	if err != nil {
 		if errors.Is(err, io.EOF) || errors.Is(err, io.ErrUnexpectedEOF) {
-			return ioutil.NopCloser(bytes.NewReader(buf[:n]))
+			return io.NopCloser(bytes.NewReader(buf[:n]))
 		}
-		return ioutil.NopCloser(bytes.NewReader(nil))
+		return io.NopCloser(bytes.NewReader(nil))
 	}
 
 	rd := io.MultiReader(bytes.NewReader(buf[:n]), reader)
@@ -338,21 +341,21 @@ func uncompressedReader(reader io.Reader) io.ReadCloser {
 	case bytes.Equal(buf[:3], []byte{0x1f, 0x8b, 0x8}):
 		r, err = gzip.NewReader(rd)
 	case bytes.Equal(buf[:3], []byte{0x42, 0x5A, 0x68}):
-		r = ioutil.NopCloser(bzip2.NewReader(rd))
+		r = io.NopCloser(bzip2.NewReader(rd))
 	case bytes.Equal(buf[:4], []byte{0x28, 0xb5, 0x2f, 0xfd}):
 		var zr *zstd.Decoder
 		zr, err = zstd.NewReader(rd)
-		r = ioutil.NopCloser(zr)
+		r = io.NopCloser(zr)
 	case bytes.Equal(buf[:4], []byte{0x04, 0x22, 0x4d, 0x18}):
-		r = ioutil.NopCloser(lz4.NewReader(rd))
+		r = io.NopCloser(lz4.NewReader(rd))
 	case bytes.Equal(buf[:7], []byte{0xfd, 0x37, 0x7a, 0x58, 0x5a, 0x0, 0x0}):
 		var zr *xz.Reader
 		zr, err = xz.NewReader(rd)
-		r = ioutil.NopCloser(zr)
+		r = io.NopCloser(zr)
 	}
 
 	if err != nil || r == nil {
-		r = ioutil.NopCloser(rd)
+		r = io.NopCloser(rd)
 	}
 	return r
 }
@@ -426,12 +429,28 @@ func expandTilde(fileName string) string {
 	return fileName
 }
 
-func trimQuote(fileName string) string {
-	if fileName[0] == '`' && fileName[len(fileName)-1] == '`' {
-		fileName = fileName[1 : len(fileName)-1]
+func trimQuote(str string) string {
+	if str[0] == '`' && str[len(str)-1] == '`' {
+		str = str[1 : len(str)-1]
 	}
-	if fileName[0] == '"' && fileName[len(fileName)-1] == '"' {
-		fileName = fileName[1 : len(fileName)-1]
+	if str[0] == '"' && str[len(str)-1] == '"' {
+		str = str[1 : len(str)-1]
 	}
-	return fileName
+	return str
+}
+
+func trimQuoteAll(str string) string {
+	if len(str) < 2 {
+		return str
+	}
+	if str[0] == '\'' && str[len(str)-1] == '\'' {
+		return str[1 : len(str)-1]
+	}
+	if str[0] == '`' && str[len(str)-1] == '`' {
+		return str[1 : len(str)-1]
+	}
+	if str[0] == '"' && str[len(str)-1] == '"' {
+		return str[1 : len(str)-1]
+	}
+	return str
 }
