@@ -13,18 +13,19 @@ import (
 	"fmt"
 	"io"
 	"log"
-	"strconv"
 
 	"github.com/itchyny/gojq"
 )
 
 // JSONReader provides methods of the Reader interface.
 type JSONReader struct {
-	reader  *json.Decoder
-	preRead []map[string]string
-	query   *gojq.Query
-	names   []string
-	types   []string
+	reader    *json.Decoder
+	preRead   []map[string]string
+	query     *gojq.Query
+	already   map[string]bool
+	names     []string
+	types     []string
+	limitRead bool
 }
 
 // NewJSONReader returns JSONReader and error.
@@ -32,13 +33,11 @@ func NewJSONReader(reader io.Reader, opts *ReadOpts) (*JSONReader, error) {
 	r := &JSONReader{}
 	r.reader = json.NewDecoder(reader)
 	r.reader.UseNumber()
+	r.already = make(map[string]bool)
 	var top interface{}
 
 	if opts.InJQuery != "" {
-		str, err := strconv.Unquote(opts.InJQuery)
-		if err != nil {
-			str = opts.InJQuery
-		}
+		str := trimQuoteAll(opts.InJQuery)
 		query, err := gojq.Parse(str)
 		if err != nil {
 			return nil, fmt.Errorf("gojq: %w (%s)", err, opts.InJQuery)
@@ -46,6 +45,8 @@ func NewJSONReader(reader io.Reader, opts *ReadOpts) (*JSONReader, error) {
 		r.query = query
 	}
 
+	r.limitRead = opts.InLimitRead
+
 	for i := 0; i < opts.InPreRead; i++ {
 		err := r.reader.Decode(&top)
 		if err != nil {
@@ -55,7 +56,6 @@ func NewJSONReader(reader io.Reader, opts *ReadOpts) (*JSONReader, error) {
 			debug.Printf(err.Error())
 			return r, nil
 		}
-
 		if r.query == nil {
 			r, err = r.readAhead(top)
 			if err != nil {
@@ -109,25 +109,18 @@ func (r *JSONReader) readAhead(top interface{}) (*JSONReader, error) {
 				return nil, err
 			}
 
-			r.names = names
+			r.appendNames(names)
 			r.preRead = append(r.preRead, pre)
 			return r, nil
 		}
 
-		already := map[string]bool{}
 		for _, v := range m {
 			pre, names, err := topLevel(v)
 			if err != nil {
 				return nil, err
 			}
 
-			for k := 0; k < len(names); k++ {
-				if !already[names[k]] {
-					already[names[k]] = true
-					r.names = append(r.names, names[k])
-				}
-			}
-
+			r.appendNames(names)
 			r.preRead = append(r.preRead, pre)
 		}
 		return r, nil
@@ -136,12 +129,22 @@ func (r *JSONReader) readAhead(top interface{}) (*JSONReader, error) {
 		if err != nil {
 			return nil, err
 		}
-		r.names = names
+		r.appendNames(names)
 		r.preRead = append(r.preRead, pre)
 	}
 	return r, nil
 }
 
+// appendNames adds multiple names for the argument to be unique.
+func (r *JSONReader) appendNames(names []string) {
+	for _, name := range names {
+		if !r.already[name] {
+			r.already[name] = true
+			r.names = append(r.names, name)
+		}
+	}
+}
+
 func topLevel(top interface{}) (map[string]string, []string, error) {
 	switch obj := top.(type) {
 	case map[string]interface{}:
@@ -167,6 +170,10 @@ func (r *JSONReader) PreReadRow() [][]interface{} {
 // ReadRow is read the rest of the row.
 // Only jsonl requires ReadRow in json.
 func (r *JSONReader) ReadRow(row []interface{}) ([]interface{}, error) {
+	if r.limitRead {
+		return nil, io.EOF
+	}
+
 	var data interface{}
 	err := r.reader.Decode(&data)
 	if err != nil {
